#  Copyright (c) 2020.  by Dheeraj Gupta.
#  This is part of json_flatten project.
#  Project: json_flatten
#  Module:
#  File: __init__.py
#  Author: Dheeraj Gupta
#  Description : tbd

# Global import
from .flatten import flatten
from .unflatten import unflatten

# Main Code


__all__ = ['flatten', 'unflatten']

